import { Inject, Controller, Post, Body, Files, Fields } from '@midwayjs/core';
import { Context } from '@midwayjs/koa';
import { Validate } from '@midwayjs/validate';
import { UserDTO } from '../dto/user.dto';
import * as tencentcloud from 'tencentcloud-sdk-nodejs';
import { VodSearchDTO } from '../dto/vod.dto';
import { BizCode } from '../biz/code';
import { uploadImagePromise } from '../util/vod';

@Controller('/api')
export class APIController {
  @Inject()
  ctx: Context;

  @Post('/get_user')
  @Validate({
    errorStatus: 422,
  })
  async getUser(@Body() user: UserDTO) {
    return { success: true, message: 'OK', data: user };
  }

  /**
   * 腾讯媒资管理查询
   * API调用demo: https://console.cloud.tencent.com/api/explorer?Product=vod&Version=2018-07-17&Action=SearchMedia
   * 最大返回5000条数据
   */
  @Post('/vod')
  async vod(@Body() param: VodSearchDTO) {
    const { offset: Offset = 0, limit: Limit = 5000 } = param;
    const VodClient = tencentcloud.vod.v20180717.Client;
    const clientConfig = {
      credential: {
        secretId: process.env.SECRET_ID,
        secretKey: process.env.SECRET_KEY,
      },
      profile: {
        httpProfile: {
          endpoint: 'vod.tencentcloudapi.com',
        },
      },
    };
    const client = new VodClient(clientConfig);
    const params = {
      SubAppId: +process.env.SUBAPPID,
      Categories: ['Video'],
      Offset,
      Limit,
    };
    return await client.SearchMedia(params).then(
      data => ({ code: BizCode.OK, data }),
      err => {
        this.ctx.logger.error(err);
        throw new Error(err);
      }
    );
  }

  @Post('/upload')
  async upload(@Files() files, @Fields() fields) {
    const tmpPath = files[0].data;
    return await uploadImagePromise(tmpPath)
      .then(data => ({ code: BizCode.OK, data }))
      .catch(err => {
        this.ctx.logger.error(err);
        throw new Error(err);
      });
  }
}
